Repository: samza
Updated Branches:
  refs/heads/master 3235929bc -> c4dfbd347


NO-JIRA: Change instances of "is catched up" to "is caught up"

Replaces any use of "catched" with "caught"

Author: Tom Butterwith <[email protected]>

Reviewers: Jagadish Venkatraman <[email protected]>, Shanthoosh 
Venkatraman <[email protected]>

This patch had conflicts when merged, resolved by
Committer: Prateek Maheshwari <[email protected]>

Closes #573 from tbutterwith/NO-TICKET/Fix-grammer-when-job-catches-up


Project: http://git-wip-us.apache.org/repos/asf/samza/repo
Commit: http://git-wip-us.apache.org/repos/asf/samza/commit/c4dfbd34
Tree: http://git-wip-us.apache.org/repos/asf/samza/tree/c4dfbd34
Diff: http://git-wip-us.apache.org/repos/asf/samza/diff/c4dfbd34

Branch: refs/heads/master
Commit: c4dfbd347c822c030ed1bee8a1c5c73bed04779c
Parents: 3235929
Author: Tom Butterwith <[email protected]>
Authored: Thu Jul 26 11:18:04 2018 -0700
Committer: Prateek Maheshwari <[email protected]>
Committed: Thu Jul 26 11:18:04 2018 -0700

----------------------------------------------------------------------
 .../scala/org/apache/samza/container/TaskInstance.scala | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/samza/blob/c4dfbd34/samza-core/src/main/scala/org/apache/samza/container/TaskInstance.scala
----------------------------------------------------------------------
diff --git 
a/samza-core/src/main/scala/org/apache/samza/container/TaskInstance.scala 
b/samza-core/src/main/scala/org/apache/samza/container/TaskInstance.scala
index d1e9b3c..d85f10f 100644
--- a/samza-core/src/main/scala/org/apache/samza/container/TaskInstance.scala
+++ b/samza-core/src/main/scala/org/apache/samza/container/TaskInstance.scala
@@ -80,7 +80,7 @@ class TaskInstance(
   val context = new TaskContextImpl(taskName, metrics, containerContext, 
systemStreamPartitions.asJava, offsetManager,
                                     kvStoreSupplier, tableManager, jobModel, 
streamMetadataCache, timerExecutor)
 
   // store the (ssp -> if this ssp is catched up) mapping. "catched up"
   // means the same ssp in other taskInstances have the same offset as
   // the one here.
   var ssp2CaughtupMapping: scala.collection.mutable.Map[SystemStreamPartition, 
Boolean] =
@@ -307,9 +307,9 @@ class TaskInstance(
     (taskName, isWindowableTask, isClosableTask, isEndOfStreamListenerTask)
 
   /**
-   * From the envelope, check if this SSP has catched up with the starting 
offset of the SSP
+   * From the envelope, check if this SSP has caught up with the starting 
offset of the SSP
    * in this TaskInstance. If the offsets are not comparable, default to true, 
which means
-   * it's already catched-up.
+   * it's already caught up.
    */
   private def checkCaughtUp(envelope: IncomingMessageEnvelope) = {
     val incomingMessageSsp = envelope.getSystemStreamPartition
@@ -319,7 +319,7 @@ class TaskInstance(
     } else {
       systemAdmins match {
         case null => {
-          warn("systemAdmin is null. Set all SystemStreamPartitions to 
catched-up")
+          warn("systemAdmin is null. Set all SystemStreamPartitions to 
caught-up")
           ssp2CaughtupMapping(incomingMessageSsp) = true
         }
         case others => {
@@ -328,12 +328,12 @@ class TaskInstance(
           val system = incomingMessageSsp.getSystem
           others.getSystemAdmin(system).offsetComparator(envelope.getOffset, 
startingOffset) match {
             case null => {
-              info("offsets in " + system + " is not comparable. Set all 
SystemStreamPartitions to catched-up")
+              info("offsets in " + system + " is not comparable. Set all 
SystemStreamPartitions to caught-up")
               ssp2CaughtupMapping(incomingMessageSsp) = true // not comparable
             }
             case result => {
               if (result >= 0) {
-                info(incomingMessageSsp.toString + " is catched up.")
+                info(incomingMessageSsp.toString + " has caught up.")
                 ssp2CaughtupMapping(incomingMessageSsp) = true
               }
             }
@@ -80,7 +80,7 @@ class TaskInstance(
streamMetadataCache, timerExecutor)
 
-  // store the (ssp -> if this ssp is catched up) mapping. "catched up"
+  // store the (ssp -> if this ssp has caught up) mapping. "caught up"
   // means the same ssp in other taskInstances have the same offset as
   // the one here.

Reply via email to